@@ -56,6 +56,59 @@ class EsRequest:
         res = r.json()
         return res
 
+    def format_es_put(self, url, body, params=None):
+        """
+        发送http请求
+        :param params:
+        :param url:
+        :param body:
+        :return:
+        """
+        r = requests.put(
+            url,
+            params=params,
+            data=json.dumps(body),
+            headers={'content-type': "application/json"},
+            auth=self.auth
+        )
+        res = r.json()
+        return res
+
+    def format_es_get(self, url, params=None):
+        """
+        发送http请求
+        :param params:
+        :param url:
+        :param body:
+        :return:
+        """
+        r = requests.get(
+            url,
+            params=params,
+            headers={'content-type': "application/json"},
+            auth=self.auth
+        )
+        res = r.json()
+        return res
+
+    def format_es_delete(self, url, body=None, params=None):
+        """
+        发送http请求
+        :param params:
+        :param url:
+        :param body:
+        :return:
+        """
+        r = requests.delete(
+            url,
+            data=json.dumps(body) if body else body,
+            params=params,
+            headers={'content-type': "application/json"},
+            auth=self.auth
+        )
+        res = r.json()
+        return res
+
     def format_scroll_url(self, host=None, port=None, route_key=None, scroll=None):
         return "http://{}:{}/{}/_search?scroll={}".format(host if host else self.host,
                                                           port if port else self.port, route_key, scroll)
@@ -68,6 +121,9 @@ class EsRequest:
         return "http://{}:{}/{}/_search".format(host if host else self.host,
                                                 port if port else self.port, route_key)
 
+    def format_url(self, path, host=None, port=None):
+        return "http://{}:{}{}".format(host if host else self.host,
+                                       port if port else self.port, path)
+
     def close(self):
         pass
-
