@@ -14,7 +14,7 @@ class SqlAlchemyHelper:
             self.pool = pool
 
     def make_session(self):
-        session = Session(self.pool)
+        session = Session(self.pool, autocommit=True)
         return session
 
 
